@@ -1,3 +1,4 @@
+//! DeleteCertificate
 use crate::v2_0_1::datatypes::certificate_hash_data_type::CertificateHashDataType;
 use crate::v2_0_1::datatypes::status_info_type::StatusInfoType;
 use crate::v2_0_1::enumerations::delete_certificate_status_enum_type::DeleteCertificateStatusEnumType;
@@ -6,6 +7,7 @@ use crate::v2_0_1::enumerations::delete_certificate_status_enum_type::DeleteCert
 #[derive(serde::Serialize, serde::Deserialize, Debug, Clone, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub struct DeleteCertificateRequest {
+    /// Indicates the certificate of which deletion isrequested.
     pub certificate_hash_data: CertificateHashDataType,
 }
 
@@ -13,8 +15,9 @@ pub struct DeleteCertificateRequest {
 #[derive(serde::Serialize, serde::Deserialize, Debug, Clone, PartialEq)]
 #[serde(rename_all = "camelCase")]
 pub struct DeleteCertificateResponse {
+    /// Charging Station indicates if it can process the request.
     pub status: DeleteCertificateStatusEnumType,
-    pub data: String,
+    /// Detailed status information.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub status_info: Option<StatusInfoType>,
 }
